package grim3212.mc.doubledoor;

import grim3212.mc.core.Grim3212Core;
import grim3212.mc.core.GrimModule;
import grim3212.mc.core.lib.Reference;
import grim3212.mc.core.util.VersionChecker;

import java.io.File;
import java.util.EnumSet;
import java.util.logging.Level;
import java.util.logging.Logger;

import net.minecraft.block.Block;
import net.minecraft.block.material.Material;
import net.minecraftforge.common.Configuration;
import cpw.mods.fml.client.FMLClientHandler;
import cpw.mods.fml.common.FMLLog;
import cpw.mods.fml.common.Mod;
import cpw.mods.fml.common.Mod.EventHandler;
import cpw.mods.fml.common.Mod.Instance;
import cpw.mods.fml.common.ModMetadata;
import cpw.mods.fml.common.TickType;
import cpw.mods.fml.common.event.FMLInitializationEvent;
import cpw.mods.fml.common.event.FMLPreInitializationEvent;
import cpw.mods.fml.common.network.NetworkMod;
import cpw.mods.fml.common.registry.GameRegistry;
import cpw.mods.fml.common.registry.TickRegistry;
import cpw.mods.fml.relauncher.Side;

@Mod(modid = DoubleDoor.modID, name = DoubleDoor.modName, version = DoubleDoor.modVersion, dependencies = "required-after:grim3212core")
@NetworkMod(clientSideRequired = true, serverSideRequired = false)
public class DoubleDoor extends GrimModule {

	@Instance(DoubleDoor.modID)
	public static DoubleDoor instance;

	public static final String modID = "grim3212doubledoor";
	public static final String modName = "Double Doors";
	public static final String modVersion = "V0.1 - " + Reference.MC_VERSION;
	public static final String modURL = "http://grim3212.wikispaces.com/DerBaM's+Mods";

	private static VersionChecker versionChecker;
	public static boolean canVersionCheck = true;
	public static boolean allowVersionCheckLocal;

	private static Logger my_log;

	@EventHandler
	public void preInit(FMLPreInitializationEvent event) {
		ModMetadata data = event.getModMetadata();
		data.autogenerated = false;
		data.version = DoubleDoor.modVersion;
		data.name = DoubleDoor.modName;
		data.description = "Makes doors, trapdoors, and fencegates be able to open at the same time instead of having to open one at a time.";
		data.authorList.add("Grim3212");
		data.authorList.add("DerBaM");
		data.url = DoubleDoor.modURL;
		data.credits = "Thanks to DerBaM for the original mod.";
		data.logoFile = Reference.LOGOFILE;

		Configuration config = new Configuration(new File(event.getModConfigurationDirectory().getAbsolutePath() + File.separator + "/GrimsMods/" + getModID() + ".cfg"));
		try {
			config.load();
			allowVersionCheckLocal = config.get(Configuration.CATEGORY_GENERAL, "Allow Version Checking For " + DoubleDoor.modName, true).getBoolean(true);
		} catch (Exception e) {
			FMLLog.log(Level.SEVERE, e, DoubleDoor.modName + " has had a problem loading it's configuration");
		} finally {
			config.save();
		}

		my_log = event.getModLog();

		TickRegistry.registerTickHandler(this, Side.CLIENT);
	}

	@EventHandler
	public void load(FMLInitializationEvent event) {
		if (Grim3212Core.doUpdateCheck) {
			versionChecker = new VersionChecker(DoubleDoor.modName, DoubleDoor.modVersion, versionUrl, DoubleDoor.modURL);
			versionChecker.checkVersionWithLoggingBySubStringAsFloat(1, 4);
		}

		int id_door_wood = Block.doorWood.blockID;
		int id_door_steel = Block.doorIron.blockID;
		int id_trap_door = Block.trapdoor.blockID;
		int id_fence_gate = Block.fenceGate.blockID;

		Block.blocksList[id_door_wood] = null;
		Block.blocksList[id_door_steel] = null;
		Block.blocksList[id_trap_door] = null;
		Block.blocksList[id_fence_gate] = null;
		net.minecraft.item.Item.itemsList[id_door_wood] = null;
		net.minecraft.item.Item.itemsList[id_door_steel] = null;
		net.minecraft.item.Item.itemsList[id_trap_door] = null;
		net.minecraft.item.Item.itemsList[id_fence_gate] = null;

		Block my_door_wood = new BlockDoorBaM(id_door_wood, Material.wood).setHardness(3.0F).setStepSound(Block.soundWoodFootstep).setUnlocalizedName("doorWood").setTextureName("door_wood");
		Block my_door_steel = new BlockDoorBaM(id_door_steel, Material.iron).setHardness(5.0F).setStepSound(Block.soundMetalFootstep).setUnlocalizedName("doorIron").setTextureName("door_iron");
		Block my_trap_door = new BlockTrapDoorBaM(id_trap_door, Material.wood).setHardness(3.0F).setStepSound(Block.soundWoodFootstep).setUnlocalizedName("trapdoor").setTextureName("trapdoor");
		Block my_fence_gate = new BlockFenceGateBaM(id_fence_gate).setHardness(2.0F).setResistance(5.0F).setStepSound(Block.soundWoodFootstep).setUnlocalizedName("fenceGate");

		GameRegistry.registerBlock(my_door_wood, "doorWood");
		GameRegistry.registerBlock(my_door_steel, "doorIron");
		GameRegistry.registerBlock(my_trap_door, "trapdoor");
		GameRegistry.registerBlock(my_fence_gate, "fenceGate");
	}

	public static void Log(String str) {
		if (my_log != null) {
			my_log.log(Level.INFO, str);
		}
	}

	@Override
	public void tickEnd(EnumSet<TickType> type, Object... tickData) {
		if (FMLClientHandler.instance().getClient().currentScreen == null) {
			if (Grim3212Core.doUpdateCheck && DoubleDoor.canVersionCheck && DoubleDoor.allowVersionCheckLocal) {
				if (!versionChecker.isCurrentVersionBySubStringAsFloatNewer(1, 4)) {
					for (String msg : versionChecker.getInGameMessage())
						FMLClientHandler.instance().getClient().ingameGUI.getChatGUI().printChatMessage(msg);
					DoubleDoor.canVersionCheck = false;
				}
			}
		}
	}

	@Override
	public String getModID() {
		return DoubleDoor.modID;
	}
}